Module vec_map

Module vec_map 

Associative maps, backed by a Vec.

Structs

Drain
An iterator over the removed key-value pairs of a map. Yields the pairs as tuples of values. Generated by the drain method.
IntoIter
An iterator over the key-value pairs of a map. Yields the pairs as tuples of values. Generated by the into_iter method.
IntoKeys
An iterator over the keys of a map. Yields the keys as values. Generated by the into_keys method.
IntoValues
An iterator over the values of a map. Yields the values as values. Generated by the into_values method.
Iter
An iterator over the key-value pairs of a map. Yields the pairs as tuples of references. Generated by the iter method.
IterMut
An iterator over the key-value pairs of a map. Yields the pairs as tuples of a reference and a mutable reference. Generated by the iter_mut method.
Keys
An iterator over the keys of a map. Yields the keys as references. Generated by the keys method.
OccupiedEntry
An occupied Entry.
VacantEntry
A vacant Entry.
Values
An iterator over the values of a map. Yields the values as references. Generated by the values method.
ValuesMut
An iterator over the values of a map. Yields the values as values. Generated by the values_mut method.
VecMap
An associative map. It is a logic error for any key to change such that its equality under the Eq trait changes while it is in the map. To determine if two keys are “the same”, Eq is used.

Enums

Entry
A view into a single key-value pair of a map. Generated by the entry method.