VecMap

Struct VecMap 

pub struct VecMap<K, V>(/* private fields */);
An associative map. It is a logic error for any key to change such that its equality under the Eq trait changes while it is in the map. To determine if two keys are “the same”, Eq is used.

Implementations

Source

impl<K, V> VecMap<K, V>

pub fn new() -> VecMap<K, V>

Create a new VecMap.

pub fn with_capacity(capacity: usize) -> VecMap<K, V>

Create a new VecMap with a given pre-allocated capacity. May allocate more than requested.

pub fn capacity(&self) -> usize

Get the allocated capacity of the map.

pub fn keys(&self) -> Keys<'_, K, V>

Get an iterator over the keys as references.

pub fn into_keys(self) -> IntoKeys<K, V>

Get an iterator over the keys.

pub fn values(&self) -> Values<'_, K, V>

Get an iterator over the values as references.

pub fn values_mut(&mut self) -> ValuesMut<'_, K, V>

Get an iterator over the values as mutable references.

pub fn into_values(self) -> IntoValues<K, V>

Get an iterator over the values.

pub fn iter(&self) -> Iter<'_, K, V>

Get an iterator over the key-value pairs as tuples of reference.

pub fn iter_mut(&mut self) -> IterMut<'_, K, V>

Get an iterator over the key-value pairs as tuples of a reference and a mutable reference.

pub fn len(&self) -> usize

Get the amount of key-value pairs in the map.

pub fn is_empty(&self) -> bool

Check if the map is empty.

pub fn drain(&mut self) -> Drain<'_, K, V>

Empty the map and return an iterator over the cleared key-value pairs.

pub fn retain<F>(&mut self, f: F)
where F: FnMut(&K, &mut V) -> bool,

Remove all key-value pairs that don’t satisfy a given predicate.

pub fn clear(&mut self)

Remove all key-value pairs.

pub fn reserve(&mut self, additional: usize)

Reserve additional space. May allocate more than requested.

Panics

Panics if the new allocation fails.

pub fn try_reserve(&mut self, additional: usize) -> Result<(), TryReserveError>

Like reserve, but returns a Result instead of panicking.

pub fn shrink_to_fit(&mut self)

Shrink the capacity of the map as much as possible. May keep more than precisely needed.

pub fn shrink_to(&mut self, min_capacity: usize)

Shrink the capacity of the map with a lower limit. May keep more than precisely needed.

Source

impl<K: Eq, V> VecMap<K, V>

pub fn entry(&mut self, key: K) -> Entry<'_, K, V>

Returns an Entry for the given key.

pub fn get<Q>(&self, k: &Q) -> Option<&V>
where K: Borrow<Q>, Q: Eq + ?Sized,

Get the given key’s value, if it exists.

pub fn get_key_value<Q>(&self, k: &Q) -> Option<(&K, &V)>
where K: Borrow<Q>, Q: Eq + ?Sized,

Get the given key’s key-value pair, if it exists.

pub fn contains_key<Q>(&self, k: &Q) -> bool
where K: Borrow<Q>, Q: Eq + ?Sized,

Check if the map contains a given key.

pub fn get_mut<Q>(&mut self, k: &Q) -> Option<&mut V>
where K: Borrow<Q>, Q: Eq + ?Sized,

Get a mutable reference to the given key’s value, if it exists.

pub fn insert(&mut self, k: K, v: V) -> Option<V>

Insert a key-value pair into the map. If the key already exists, the old value is returned.

pub fn remove<Q>(&mut self, k: &Q) -> Option<V>
where K: Borrow<Q>, Q: Eq + ?Sized,

Remove the given key’s key-value pair from the map. Returns the removed value, if it existed.

pub fn remove_entry<Q>(&mut self, k: &Q) -> Option<(K, V)>
where K: Borrow<Q>, Q: Eq + ?Sized,

Remove the given key’s key-value pair from the map. Returns the removed key-value pair, if it existed.

Source

impl<K: Eq, V: PartialEq> VecMap<K, V>

pub fn eq_ordered(&self, other: &Self) -> bool

Check two maps for equality while considering the order of key-value pairs.