Module vec_set

Module vec_set 

Sets, backed by a Vec.

Structs

Difference
An iterator over the set difference between two sets. Yields the values as references. Generated by the difference method.
Drain
An iterator over the removed values of a set. Yields the values as values. Generated by the drain method.
Intersection
An iterator over the intersection of two sets. Yields the values as references. Generated by the intersection method.
IntoIter
An iterator over the values of a set. Yields the values as values. Generated by the into_iter method.
Iter
An iterator over the values of a set. Yields the values as references. Generated by the iter method
SymmetricDifference
An iterator over the symmetric set difference between two sets. Yields the values as references. Generated by the symmetric_difference method.
Union
An iterator over the union of two sets. Yields the values as references. Generated by the union method.
VecSet
A set. It is a logic error for any value to change such that its equality under the Eq trait changes while it is in the set. To determine if two values are “the same”, Eq is used.