Associative maps, backed by a Vec.
Structs
- Drain
- An iterator over the removed key-value pairs of a map.
Yields the pairs as tuples of values.
Generated by the
drainmethod. - Into
Iter - An iterator over the key-value pairs of a map.
Yields the pairs as tuples of values.
Generated by the
into_itermethod. - Into
Keys - An iterator over the keys of a map.
Yields the keys as values.
Generated by the
into_keysmethod. - Into
Values - An iterator over the values of a map.
Yields the values as values.
Generated by the
into_valuesmethod. - Iter
- An iterator over the key-value pairs of a map.
Yields the pairs as tuples of references.
Generated by the
itermethod. - IterMut
- An iterator over the key-value pairs of a map.
Yields the pairs as tuples of a reference and a mutable reference.
Generated by the
iter_mutmethod. - Keys
- An iterator over the keys of a map.
Yields the keys as references.
Generated by the
keysmethod. - Occupied
Entry - An occupied
Entry. - Vacant
Entry - A vacant
Entry. - Values
- An iterator over the values of a map.
Yields the values as references.
Generated by the
valuesmethod. - Values
Mut - An iterator over the values of a map.
Yields the values as values.
Generated by the
values_mutmethod. - VecMap
- An associative map.
It is a logic error for any key to change such that its equality
under the
Eqtrait changes while it is in the map. To determine if two keys are “the same”,Eqis used.