pub struct VecMap<K, V>(/* private fields */);Expand description
Implementations
Sourceimpl<K, V> VecMap<K, V>
impl<K, V> VecMap<K, V>
Sourcepub fn with_capacity(capacity: usize) -> VecMap<K, V>
pub fn with_capacity(capacity: usize) -> VecMap<K, V>
Create a new VecMap with a given pre-allocated capacity.
May allocate more than requested.
Sourcepub fn values_mut(&mut self) -> ValuesMut<'_, K, V> ⓘ
pub fn values_mut(&mut self) -> ValuesMut<'_, K, V> ⓘ
Get an iterator over the values as mutable references.
Sourcepub fn into_values(self) -> IntoValues<K, V> ⓘ
pub fn into_values(self) -> IntoValues<K, V> ⓘ
Get an iterator over the values.
Sourcepub fn iter(&self) -> Iter<'_, K, V> ⓘ
pub fn iter(&self) -> Iter<'_, K, V> ⓘ
Get an iterator over the key-value pairs as tuples of reference.
Sourcepub fn iter_mut(&mut self) -> IterMut<'_, K, V> ⓘ
pub fn iter_mut(&mut self) -> IterMut<'_, K, V> ⓘ
Get an iterator over the key-value pairs as tuples of a reference and a mutable reference.
Sourcepub fn drain(&mut self) -> Drain<'_, K, V> ⓘ
pub fn drain(&mut self) -> Drain<'_, K, V> ⓘ
Empty the map and return an iterator over the cleared key-value pairs.
Sourcepub fn retain<F>(&mut self, f: F)
pub fn retain<F>(&mut self, f: F)
Remove all key-value pairs that don’t satisfy a given predicate.
Sourcepub fn reserve(&mut self, additional: usize)
pub fn reserve(&mut self, additional: usize)
Reserve additional space. May allocate more than requested.
Panics
Panics if the new allocation fails.
Sourcepub fn try_reserve(&mut self, additional: usize) -> Result<(), TryReserveError>
pub fn try_reserve(&mut self, additional: usize) -> Result<(), TryReserveError>
Sourcepub fn shrink_to_fit(&mut self)
pub fn shrink_to_fit(&mut self)
Shrink the capacity of the map as much as possible. May keep more than precisely needed.
Sourceimpl<K: Eq, V> VecMap<K, V>
impl<K: Eq, V> VecMap<K, V>
Sourcepub fn get_key_value<Q>(&self, k: &Q) -> Option<(&K, &V)>
pub fn get_key_value<Q>(&self, k: &Q) -> Option<(&K, &V)>
Get the given key’s key-value pair, if it exists.
Sourcepub fn contains_key<Q>(&self, k: &Q) -> bool
pub fn contains_key<Q>(&self, k: &Q) -> bool
Check if the map contains a given key.
Sourcepub fn get_mut<Q>(&mut self, k: &Q) -> Option<&mut V>
pub fn get_mut<Q>(&mut self, k: &Q) -> Option<&mut V>
Get a mutable reference to the given key’s value, if it exists.
Sourcepub fn insert(&mut self, k: K, v: V) -> Option<V>
pub fn insert(&mut self, k: K, v: V) -> Option<V>
Insert a key-value pair into the map. If the key already exists, the old value is returned.