Sets, backed by a Vec.
Structs
- Difference
- An iterator over the set difference between two sets.
Yields the values as references.
Generated by the
differencemethod. - Drain
- An iterator over the removed values of a set.
Yields the values as values.
Generated by the
drainmethod. - Intersection
- An iterator over the intersection of two sets.
Yields the values as references.
Generated by the
intersectionmethod. - Into
Iter - An iterator over the values of a set.
Yields the values as values.
Generated by the
into_itermethod. - Iter
- An iterator over the values of a set.
Yields the values as references.
Generated by the
itermethod - Symmetric
Difference - An iterator over the symmetric set difference between two sets.
Yields the values as references.
Generated by the
symmetric_differencemethod. - Union
- An iterator over the union of two sets.
Yields the values as references.
Generated by the
unionmethod. - VecSet
- A set.
It is a logic error for any value to change such that its equality
under the
Eqtrait changes while it is in the set. To determine if two values are “the same”,Eqis used.